Crate blwf

Crate blwf 

Re-exports

pub use wgpu;
pub use winit;

Structs

Error
The Error type, a wrapper around a dynamic error type.
WgpuBase
WgpuBase handles the initialization of wgpu and stores the wgpu resources that every app will need (device, queue, surface, surface configuration). It also stores a handle to the window. One of these should be contained in your app.

Traits

WgpuApplication

Functions

run

Type Aliases

Result
Result<T, Error>